/*******************************************************************************
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
package com.ofss.digx.app.account.adapter.impl;

import com.ofss.digx.app.account.adapter.IAccountAdapter;
import com.ofss.digx.app.adapter.AdapterFactory;
import com.ofss.digx.app.adapter.AdapterMockingConfigurator;
import com.ofss.digx.datatype.NameValuePair;

/**
 * Factory for the adaptors implementing the host level functions for Account. Responsible for instantiating an
 * object of Class {@link AccountAdapter}.
 * 
 */
public class AccountAdapterFactory extends AdapterFactory{
	/**
	 * Instance of {@link AccountAdapterFactory} class.
	 */
	private static AccountAdapterFactory uniqueInstance = null;

	/**
	 * This attribute holds the fact whether Event Processing is mocked or not.
	 */
	private boolean isAccountAdapterMocked = AdapterMockingConfigurator.getInstance().isAdapterMocked(
			"ACCOUNT_CZ_ADAPTER_MOCKED");
	/**
	 * Constant for Account Adapter
	 */
	private String ACCOUNT_ADAPTER = "ACCOUNT_ADAPTER";

	/**
	 * Creates a new instance of class {@link AccountAdapterFactory}
	 * 
	 * @return uniqueInstance Adapter Factory which is the object of this class.
	 */
	public static AccountAdapterFactory getInstance() {
		if (uniqueInstance == null) {
			synchronized (AccountAdapterFactory.class) {
				uniqueInstance = new AccountAdapterFactory();
			}
		}
		return uniqueInstance;
	}

	/**
	 * A call to this factory method is made whenever a new instance of class {@link IAccountAdapter} is to be
	 * created. It returns an instance of type {@link IAccountAdapter}
	 * 
	 * @param adapterName
	 *            - {@code java.lang.String} containing the name of required adapter class.
	 * @return {@link IAccountAdapter} containing instance of the required adapter class.
	 */
	@Override
	public IAccountAdapter getAdapter(String adapterName) {
		IAccountAdapter adapter = null;
		if (!isAccountAdapterMocked) {
			if (adapterName.equals(ACCOUNT_ADAPTER)) {
				adapter = new AccountAdapter();
			}
		} else {
			adapter = new AccountMockAdapter();
		}
		return adapter;
	}

	/**
	 * Returns an implementation of adapter, used in case of multiple factories inside a factory. As the adapter
	 * implementations are different, the instance returned by this factory is generic of type Object.
	 * 
	 * @param adapter
	 *            - containing the name of required adapter class.
	 * @param nameValues
	 *            - {@link NameValuePair} an array of configuration factories needed.
	 * @return object of the required adapter.
	 */
	@Override
	public Object getAdapter(String adapter, NameValuePair[] nameValues) {
		return null;
	}
}





