/*******************************************************************************
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
package com.ofss.digx.app.account.dto;

import com.ofss.fc.framework.domain.common.dto.DataTransferObject;

/**
 * Request parameter data transfer object containing account related details
 *
 */
public class AccountRequestDTO extends DataTransferObject{

	/**
	 * Serial version UID
	 */
	private static final long serialVersionUID = -8590989516065747403L;

	/**
	 * The identifier to uniquely identify the bank code in which the account is held.
	 */
	private String bankCode;
	
	/**
	 * Unique identifier for the account.
	 */
	private String accountId;
	
	/**
	 * IBAN stands for International Bank Account Number, which can be used when making or receiving international
	 * payments. IBAN does not replace sort code & account number - it's and additional number with extra information to
	 * help overseas banks identify an account for payments.
	 */
	private boolean isIban;
	
	/**
	 * Boolean to store whether the account is internal or not.
	 */
	private boolean isInternalAccount;
    /**
     * Returns bank code in which account is held.
     * @return bankCode
     */
	public String getBankCode() {
		return bankCode;
	}
	/**
	 * Sets bank code in which account is held.
	 * @param bankCode
	 */
	public void setBankCode(String bankCode) {
		this.bankCode = bankCode;
	}
	/**
	 * Fetches account number of the customer.
	 * @return accountId 
	 */
	public String getAccountId() {
		return accountId;
	}
	/**
	 * Sets account number of the customer.
	 * @param accountId
	 */
	public void setAccountId(String accountId) {
		this.accountId = accountId;
	}
	/**
	 * Gets the boolean value of isIban attribute.
	 * @return isIban
	 */
	public boolean isIban() {
		return isIban;
	}
	/**
	 * Sets the boolean value of isIban attribute.
	 * @param isIban
	 */
	public void setIban(boolean isIban) {
		this.isIban = isIban;
	}
	/**
	 * Gets the boolean value of isInternalAccount attribute.
	 * @return isInternalAccount
	 */
	public boolean isInternalAccount() {
		return isInternalAccount;
	}
	/**
	 * Sets the boolean value of isInternalAccount attribute.
	 * @param isInternalAccount
	 */
	public void setInternalAccount(boolean isInternalAccount) {
		this.isInternalAccount = isInternalAccount;
	}
	
}
