/*******************************************************************************
 * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/

package com.ofss.digx.app.account.dto;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.ofss.digx.infra.esapi.AbstractCanonicalizer;
import com.ofss.fc.infra.log.impl.MultiEntityLogger;

/**
 * 
 * Canonicalizer of the {@link AccountRequestDTO} class. It is used to canonicalize the objects of
 * {@link AccountRequestDTO}. It uses ESAPI to canonicalize the string data members of the object.
 *
 */
public class AccountRequestDTOCanonicalizer extends AbstractCanonicalizer<AccountRequestDTO>{

    /**
	 * Serial Version UID
	 */
    private static final long serialVersionUID = 3513493083414458539L;

    /**
	 * Name of the entity(class) represented by this {@code Class} object as a {@code String}.
	 */
    private static final String THIS_COMPONENT_NAME = AccountRequestDTOCanonicalizer.class.getName();

    /**
	 * Create instance of multi-entity logger.
	 */
    private MultiEntityLogger formatter = MultiEntityLogger.getUniqueInstance();

    /***
	 * This is an instance variable which is required to support multi-entity wide logging.
	 */
    private static final Logger logger = MultiEntityLogger.getUniqueInstance().getLogger(THIS_COMPONENT_NAME);

    /**
	 * Public Constructor.
	 */
    public AccountRequestDTOCanonicalizer() {
    }

    /**
	 * Canonicalizes every String data member of the {@link AccountRequestDTO} object. It traverses inner DTOs also to
	 * canonicalize the inner String data members by making call to their respective class-canonicalizers.
	 * 
	 * @param accountDTO
	 *            An object of {@link AccountRequestDTO} to be canonicalized.
	 * @return accountDTO Canonicalized object of {@link AccountRequestDTO}.
	 */
    @Override
    public AccountRequestDTO canonicalize(AccountRequestDTO accountDTO) {
        try {
            accountDTO.setAccountId(esapiHelper.canonicalizeObject(accountDTO.getAccountId()));
            accountDTO.setBankCode(esapiHelper.canonicalizeObject(accountDTO.getBankCode()));
        } catch (Exception e) {
            logger.log(Level.SEVERE, formatter.formatMessage("Fatal error while canonicalizing AccountRequestDTO object."), e);
        }
        return accountDTO;
    }

}