package com.ofss.digx.app.account.dto;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.ofss.digx.infra.esapi.AbstractDataEncoder;
import com.ofss.fc.infra.log.impl.MultiEntityLogger;
/**
 * 
 * Encoder of the {@link AccountResponseDTO} class. It is used to encode the objects of {@link AccountResponseDTO}. It uses
 * ESAPI to encode the string data members of the object.
 *
 */
public class AccountResponseDTOEncoder extends AbstractDataEncoder<AccountResponseDTO>{
	/**
	 * Name of the entity(class) represented by this {@code Class} object as a {@code String}
	 */
    private static final String THIS_COMPONENT_NAME = AccountResponseDTOEncoder.class.getName();

    /**
	 * Create instance of multi-entity logger
	 */
    private MultiEntityLogger formatter = MultiEntityLogger.getUniqueInstance();

    /***
	 * This is an instance variable which is required to support multi-entity wide logging.
	 */
    private static final Logger logger = MultiEntityLogger.getUniqueInstance().getLogger(THIS_COMPONENT_NAME);

    /**
	 * Public Constructor.
	 */
    public AccountResponseDTOEncoder() {
    }

    /**
	 * Encodes every String data member of the {@link AccountResponseDTO} object. It traverses inner DTOs also to encode
	 * the inner String data members by making call to their respective class-encoders.
	 * 
	 * @param accountDTO
	 *            An object of {@link AccountResponseDTO} to be encoded.
	 * @return accountDTO Encoded object of {@link AccountResponseDTO}.
	 */
    @Override
    public AccountResponseDTO encode(AccountResponseDTO accountDTO) {
        try {
        	accountDTO.setAccountId(esapiHelper.encode(accountDTO.getAccountId()));
        	accountDTO.setTitle(esapiHelper.encode(accountDTO.getTitle()));
        	accountDTO.setBankCode(esapiHelper.encode(accountDTO.getBankCode()));
        } catch (Exception e) {
            logger.log(Level.SEVERE, formatter.formatMessage("Fatal error while encoding AccountResponseDTO object."), e);
        }
        return accountDTO;
    }
}
