/*******************************************************************************
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
package com.ofss.digx.app.account.assembler;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.ofss.digx.app.account.dto.AccountRequestDTO;
import com.ofss.digx.app.account.dto.AccountResponseDTO;
import com.ofss.digx.domain.account.entity.Account;
import com.ofss.digx.domain.account.entity.AccountKey;
import com.ofss.digx.infra.exceptions.Exception;
import com.ofss.fc.framework.domain.IAbstractDomainObject;
import com.ofss.fc.framework.domain.assembler.AbstractAssembler;
import com.ofss.fc.framework.domain.common.dto.DomainObjectDTO;
import com.ofss.fc.infra.exception.FatalException;
import com.ofss.fc.infra.log.impl.MultiEntityLogger;

/**
 * Helper class of DIGX framework to convert Data transfer object into domain(database) compatible data object classes and vice versa.
 *
 */
public class AccountAssembler extends AbstractAssembler<IAbstractDomainObject, DomainObjectDTO>{
	/**
	 * The fully qualified name of the current component.
	 */
	private static final String THIS_COMPONENT_NAME = AccountAssembler.class.getName();
	/**
	 * The logger used for logging exceptions while assembling.
	 */
	private transient Logger LOGGER = MultiEntityLogger.getUniqueInstance().getLogger(THIS_COMPONENT_NAME);

	
	/**
	 * Method to override
	 */
	@Override
	public DomainObjectDTO fromDomainObject(IAbstractDomainObject arg0)
			throws FatalException {
		
		return null;
	}
	/**
	 * Method to override
	 */
	@Override
	public IAbstractDomainObject toDomainObject(DomainObjectDTO arg0)
			throws FatalException {
	
		return null;
	}
	/**
	 * Converts {@link AccountAccessDTO}, a data transfer object to {@link Account}, a domain object for Account service.
	 * 
	 * @param accountDTO
	 *            of type {@link AccountRequestDTO} representing Account related data object.
	 * @return accountDomain {@link Account} representing Account domain object
	 * @throws com.ofss.digx.infra.exceptions.Exception
	 *             if any error occurs while mapping from {@link AccountRequestDTO} data transfer object to
	 *             {@link Account} domain object.
	 * 
	 */
	public Account toDomainObject(AccountRequestDTO accountDTO) throws com.ofss.digx.infra.exceptions.Exception{		
		Account accountDomain = new Account();
		if (accountDTO != null) {
			populateDataTransferObjectDTOMap("com.ofss.digx.app.account.dto.AccountDTO", accountDTO);
			try {
				if (retrieveDataTransferObjectDTOMapElement("com.ofss.digx.app.account.dto.AccountDTO")
						.getDictionaryArray() != null) {
					accountDomain = (Account) getCustomizedDomainObject(
							retrieveDataTransferObjectDTOMapElement("com.ofss.digx.app.account.dto.AccountDTO"));
				}
			} catch (java.lang.Exception e) {
				LOGGER.log(Level.WARNING, "Customized Domain Object failed to be instantiated from "
						+ "com.ofss.digx.app.account.dto.AccountDTO", e);
			}
			AccountKey key = new AccountKey();
			key.setAccountId(accountDTO.getAccountId());
			accountDomain.setKey(key);
			accountDomain.setBankCode(accountDTO.getBankCode());
			accountDomain.setIban(accountDTO.isIban());
			accountDomain.setInternalAccount(accountDTO.isInternalAccount());
		}
		return accountDomain;
	}
	
	/**
	 * Converts {@link Account}, a domain object to {@link AccountResponseDTO}, data transfer object for Account Service.
	 * 
	 * @param accountDomain
	 *            of type {@link Account} representing Account domain object.
	 * @return accountDTO {@link AccountResponseDTO} representing Account data transfer object
	 * @throws com.ofss.digx.infra.exceptions.Exception
	 *             if any error occurs while mapping from {@link AccountResponseDTO} data transfer object to
	 *             {@link Account} domain object.
	 * 
	 */

	public AccountResponseDTO fromDomainObject(Account accountDomain) throws Exception {
		
		AccountResponseDTO accountDTO = new AccountResponseDTO();
		if (accountDomain != null) {			
			populateAbstractDomainObjectMap("com.ofss.digx.domain.account.entity.Account", accountDomain);
			if (accountDomain.getKey() != null) {
				accountDTO.setAccountId(accountDomain.getKey().getAccountId());
			}
			if(accountDomain.getKey()!=null){
			accountDTO.setAccountId(accountDomain.getKey().getAccountId());}
			accountDTO.setBankCode(accountDomain.getBankCode());
			accountDTO.setIban(accountDomain.isIban());
			accountDTO.setInternalAccount(accountDomain.isInternalAccount());
			accountDTO.setTitle(accountDomain.getTitle());
			accountDTO.setDictionaryArray(getDictionaryArray(accountDomain));			
		}
		return accountDTO;
	}

	
	
	
}
