/*******************************************************************************
 * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
/**
 * 
 */
package com.ofss.digx.app.account.service.ext;

import com.ofss.digx.app.account.dto.AccountRequestDTO;
import com.ofss.digx.app.account.dto.AccountResponseDTO;
import com.ofss.digx.app.account.service.Account;
import com.ofss.fc.app.context.SessionContext;



/**
 * Represents extension executor interface as hook point for {@link Account}.</br> Extensions can be called before/after
 * executing business logic of service. These methods are available in class with 'pre and post' as prefix of the actual
 * method name. The implementation of these methods depend upon the actual business requirement under different cases.
 */
public interface IAccountExtExecutor {

	/**
	 * Processes before the execution of actual business logic for fetching account details. Calls all the pre executional
	 * methods of all the extensions.
	 * 
	 * @param sessionContext
	 *            {@link SessionContext} containing session details
	 * @param accountRequest
	 *            {@link AccountRequestDTO} containing filters to fetch account list.
	 * @throws Exception
	 *             if any exception occurs.
	 */
	public void preFetch(SessionContext sessionContext, AccountRequestDTO accountRequest) throws com.ofss.digx.infra.exceptions.Exception;

	/**
	 * Processes after the execution of actual business logic for fetching account details. Calls all the post executional
	 * methods of all the extensions.
	 * 
	 * @param sessionContext
	 *            {@link SessionContext} containing session details
	 * @param accountRequest
	 *            {@link AccountRequestDTO} containing filters to fetch account list.
	 * @param accountResponse
	 *            {@link AccountResponseDTO} containing account list.
	 * @throws Exception
	 *             if any exception occurs.
	 */
	public void postFetch(SessionContext sessionContext, AccountRequestDTO accountRequest,
	AccountResponseDTO accountResponse) throws com.ofss.digx.infra.exceptions.Exception;
}
