/*******************************************************************************
 * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
/**
 * 
 */
package com.ofss.digx.app.account.service.ext;

import com.ofss.digx.app.account.dto.AccountRequestDTO;
import com.ofss.digx.app.account.dto.AccountResponseDTO;
import com.ofss.digx.app.account.service.Account;
import com.ofss.fc.app.context.SessionContext;


/**
 * Represents service extension as hook point for {@link Account}.</br> Extensions can be called before/after executing
 * business logic of service. These methods are available in class with 'pre and post' as prefix of the actual method
 * name. The implementation of these methods depend upon the actual business requirement under different cases.
 */
public class VoidAccountExt implements IAccountExt {

	/**
	 * Processes before the execution of actual business logic for fetching account list. Executes the pre extension
	 * logic before the actual business logic.
	 * 
	 * @param sessionContext
	 *            {@link SessionContext} containing session details
	 * @param accountListRequest
	 *            {@link AccountListRequest} containing filters to fetch account list.
	 * @throws Exception
	 *             if any exception occurs.
	 */
	@Override
	public void preFetch(SessionContext sessionContext, AccountRequestDTO accountRequest) throws com.ofss.digx.infra.exceptions.Exception {

	}

	/**
	 * Processes after the execution of actual business logic for fetching account list. Executes the post extension
	 * logic before the actual business logic.
	 * 
	 * @param sessionContext
	 *            {@link SessionContext} containing session details
	 * @param accountListRequest
	 *            {@link AccountListRequest} containing filters to fetch account list.
	 * @param accountListResponse
	 *            {@link AccountListResponse} containing account list.
	 * @throws Exception
	 *             if any exception occurs.
	 */
	@Override
	public void postFetch(SessionContext sessionContext, AccountRequestDTO accountRequest,
		AccountResponseDTO accountResponse) throws com.ofss.digx.infra.exceptions.Exception {

	}

}
