/*******************************************************************************
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
package com.ofss.digx.domain.account.entity;

import com.ofss.digx.domain.account.entity.repository.AccountRepository;
import com.ofss.digx.infra.exceptions.Exception;
import com.ofss.fc.framework.domain.AbstractDomainObject;
import com.ofss.fc.framework.domain.IPersistenceObject;


/**
 * Domain class for Account Entity. It contains all the fields that need to be persisted or are involved in CRUD operations of database. 
 */
public class Account extends AbstractDomainObject implements IPersistenceObject {

	/**
	 * Serial version UID
	 */
	private static final long serialVersionUID = -3860599808521079687L;
	/**
	 * Method to override
	 */
	@Override
	protected void validate() {		
		
	}
	
	/**
	 * The identifier to uniquely identify the bank code in which the account is held.
	 */
	private String bankCode;
	
	/**
	 * Unique identifier for the account.
	 */
	private AccountKey key;
	
	/**
	 * IBAN stands for International Bank Account Number, which can be used when making or receiving international
	 * payments. IBAN does not replace sort code & account number - it's and additional number with extra information to
	 * help overseas banks identify an account for payments.
	 */
	private boolean isIban;
	
	/**
	 * Boolean value to store whether the account is internal or not.
	 */
	private boolean isInternalAccount;	

	/**
	 * The identifier to uniquely identify the bank code in which the account is held.
	 */
	private String title;
	
    /**
     * Returns bank code in which account is held.
     * @return bankCode
     */
	public String getBankCode() {
		return bankCode;
	}
	/**
	 * Sets bank code in which account is held.
	 * @param bankCode
	 */
	public void setBankCode(String bankCode) {
		this.bankCode = bankCode;
	}
	/**
	 * Fetches account number of the customer.
	 * @return accountId 
	 */
	public AccountKey getKey() {
		return key;
	}
	/**
	 * Sets account number of the customer.
	 * @param key
	 */
	public void setKey(AccountKey key) {
		this.key = key;
	}
	/**
	 * Gets the boolean value of isIban attribute.
	 * @return isIban
	 */
	public boolean isIban() {
		return isIban;
	}
	/**
	 * Sets the boolean value of isIban attribute.
	 * @param isIban
	 */
	public void setIban(boolean isIban) {
		this.isIban = isIban;
	}
	/**
	 * Gets the boolean value of isInternalAccount attribute.
	 * @return isInternalAccount
	 */
	public boolean isInternalAccount() {
		return isInternalAccount;
	}
	/**
	 * Sets the boolean value of isInternalAccount attribute.
	 * @param isInternalAccount
	 */
	public void setInternalAccount(boolean isInternalAccount) {
		this.isInternalAccount = isInternalAccount;
	}
	/**
     * Returns account title of the customer.
     * @return bankCode
     */
	public String getTitle() {
		return title;
	}
	/**
	 * Sets account title of the customer
	 * @param bankCode
	 */
	public void setTitle(String title) {
		this.title = title;
	}
	/**
	 * Performs fetch operation on the basis of request parameter values.
	 * @param account containing request details 
	 * @return account domain containing desired response
	 * @throws Exception in case of any exception from persistence storage.
	 */
	public Account fetch(Account account) throws Exception{
		Account accountDomain = new Account();
		AccountRepository repository = AccountRepository.getInstance();
		accountDomain = repository.fetch(account);
		return accountDomain;
	}
	
}
