/*******************************************************************************
 * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
/**
 * 
 */
package com.ofss.digx.domain.account.entity;

import com.ofss.fc.framework.domain.AbstractDomainObjectKey;
import com.ofss.fc.infra.text.mask.MaskingFactory;

/**
 * Key Class for {@link Account}. An entity class may use other fine-grained classes to represent the entity state.
 * These classes are called embeddable classes and do not have any persistent entity of their own. </br>They exist only
 * as embedded objects of the entity to which they belong. The AccountKey is one such embedded class which acts as the
 * primary key for the {@link Account} Domain Object.
 */

public class AccountKey extends AbstractDomainObjectKey {

	/**
	 * Serial Version UID.
	 */
	private static final long serialVersionUID = 1466271303860967873L;
	/**
	 * The identifier of the Account.
	 **/
	String accountId;

	/**
	 * Returns the id or null as default value if no value is set.
	 * 
	 * @return id as the accountId
	 */
	public String getAccountId() {
		return accountId;
	}

	/**
	 * Sets the id of the account input domain object key.
	 * 
	 * @param accountId
	 *            the accountId to set
	 */
	public void setAccountId(String accountId) {
		this.accountId = accountId;
	}

	/**
	 * toString() method implementation appends all the fields declared in the class to a StringBuffer .
	 * 
	 * @return in the form of {@link String}.
	 *
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "AccountKey [accountId="
				+ MaskingFactory.getInstance().mask(accountId, "AccountNumberMasking", "account_id") + "]";
	}

	/**
	 * Implementation appends all the fields declared in the class to a StringBuffer.
	 * 
	 * @return in the form of {@link String}.
	 */
	@Override
	public String keyAsString() {
		return getAccountId();
	}
}