package com.ofss.digx.domain.account.entity.assembler;

import com.ofss.digx.app.account.dto.AccountRequestDTO;
import com.ofss.digx.app.account.dto.AccountResponseDTO;
import com.ofss.digx.domain.account.entity.Account;
import com.ofss.digx.domain.account.entity.AccountKey;
import com.ofss.digx.framework.domain.assembler.AbstractAssembler;
import com.ofss.fc.framework.domain.IAbstractDomainObject;
import com.ofss.fc.framework.domain.common.dto.DomainObjectDTO;
/**
 * Assembler class to convert domain side data transfer object to domain object and vice versa
 *
 */
@SuppressWarnings("rawtypes")
public class AccountDomainAssembler extends AbstractAssembler{

	/**
	 * Converts Domain object to Data Transfer Object
	 * @param accountDomain
	 * @return requestDTO
	 * @throws Exception
	 */
	public AccountRequestDTO fromDomainObject(Account accountDomain) throws com.ofss.digx.infra.exceptions.Exception{
		AccountRequestDTO requestDTO = new AccountRequestDTO();
		if(accountDomain!=null){
			requestDTO.setBankCode(accountDomain.getBankCode());
			requestDTO.setIban(accountDomain.isIban());
			requestDTO.setInternalAccount(accountDomain.isInternalAccount());
			if(accountDomain.getKey()!=null){
			requestDTO.setAccountId(accountDomain.getKey().getAccountId());}
		}
		
		return requestDTO;
	}
	
	/**
	 * Converts Data Transfer Object to Domain object 
	 * @param accountDTO
	 * @return accountDomain
	 * @throws Exception
	 */
	public Account toDomainObject(AccountResponseDTO accountDTO) throws com.ofss.digx.infra.exceptions.Exception{
		Account accountDomain = new Account();
		if(accountDTO!=null){
			accountDomain.setBankCode(accountDTO.getBankCode());
			accountDomain.setIban(accountDTO.isIban());
			accountDomain.setInternalAccount(accountDTO.isInternalAccount());
			accountDomain.setTitle(accountDTO.getTitle());
			AccountKey key = new AccountKey();
			key.setAccountId(accountDTO.getAccountId());
			accountDomain.setKey(key);
		}

		
		return accountDomain;
	}
	/**
	 * Method to override
	 */
	@Override
	public DomainObjectDTO fromDomainObjectToDTO(IAbstractDomainObject arg0)
			throws com.ofss.digx.infra.exceptions.Exception {
		return null;
	}
	/**
	 * Method to override
	 */
	@Override
	public IAbstractDomainObject toDomainObjectFromDTO(DomainObjectDTO arg0)
			throws com.ofss.digx.infra.exceptions.Exception {
		return null;
	}
}
