package com.ofss.digx.domain.account.entity.policy;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.ofss.fc.framework.domain.policy.AbstractBusinessPolicy;
import com.ofss.fc.framework.domain.policy.AbstractBusinessPolicyFactory;
import com.ofss.fc.framework.domain.policy.IBusinessPolicyDTO;
import com.ofss.fc.infra.log.impl.MultiEntityLogger;
/**
 * Business Policy Factory class used to instantiate respective Business Policy Classes of Account Service
 *
 */
public class AccountBusinessPolicyFactory extends AbstractBusinessPolicyFactory{
	/**
	 * Stores the name of the entity(class) represented by this {@code Class} object as a {@code String}
	 */
	private static final String THIS_COMPONENT_NAME = AccountBusinessPolicyFactory.class.getName();
	
	/**
	 * Create instance of multi-entity logger
	 */
	private static final MultiEntityLogger FORMATTER = MultiEntityLogger.getUniqueInstance();
	/**
	 * This is an instance variable which is required to support multi-entity wide logging.
	 */
	private static final Logger LOGGER = FORMATTER.getLogger(THIS_COMPONENT_NAME);

	/**
	 * This attribute represents the policy factory instance.
	 */
	private static AccountBusinessPolicyFactory uniqueInstance = new AccountBusinessPolicyFactory();
	/**
	 * Variable to store Business Policy Class Constant
	 */
	private String ACCOUNT_BUSINESS_READ_POLICY = "ACCOUNT_BUSINESS_READ_POLICY";

	/**
	 * Returns the unique instance of this class.
	 * 
	 * Check the existence of this object. If the object exists it returns otherwise it creates and returns the same.
	 * 
	 * @return uniqueInstance
	 */
	public static AccountBusinessPolicyFactory getInstance() {

		return uniqueInstance;
	}

	/**
	 * Creates AbstractBusinessPolicy instance
	 * 
	 * @param policyId
	 *            { @link String} unique identifier for policy
	 * @param iBusinessPolicyDTO
	 *            {@link IBusinessPolicyDTO } DTO class for business policy of account service
	 * 
	 * @return {@link AbstractBusinessPolicy}
	 */
	public AbstractBusinessPolicy createPolicyInstance(String policyId, IBusinessPolicyDTO iBusinessPolicyDTO) {
		if (LOGGER.isLoggable(Level.FINE)) {
			LOGGER.log(
					Level.FINE,
					FORMATTER
							.formatMessage("Entered into com.ofss.digx.domain.account.entity.policy.AccountBusinessPolicyFactory.createPolicyInstance() "));
		}
		AbstractBusinessPolicy abstractBusinessPolicy = super.getBusinesPolicyInstance(policyId, iBusinessPolicyDTO);
		if (abstractBusinessPolicy == null) {
			if (ACCOUNT_BUSINESS_READ_POLICY.equals(policyId)) {
				abstractBusinessPolicy = new AccountReadBusinessPolicy(
						(AccountBusinessPolicyDTO) iBusinessPolicyDTO);
			}
			
			if (LOGGER.isLoggable(Level.FINE)) {
				LOGGER.log(
						Level.FINE,
						FORMATTER
								.formatMessage("Exiting from com.ofss.digx.domain.account.entity.policy.AccountBusinessPolicyFactory.createPolicyInstance() "));
			}

		}
		return abstractBusinessPolicy;

	}
}
