/*******************************************************************************
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
package com.ofss.digx.domain.account.entity.repository;

import com.ofss.digx.domain.account.entity.Account;
import com.ofss.digx.domain.account.entity.AccountKey;
import com.ofss.digx.domain.account.entity.repository.adapter.IAccountRepositoryAdapter;
import com.ofss.digx.domain.account.entity.repository.adapter.RemoteAccountRepositoryAdapter;
import com.ofss.digx.framework.domain.repository.AbstractDomainObjectRepository;
import com.ofss.digx.framework.domain.repository.RepositoryAdapterFactory;
/**
 * Repository class responsible for communicating with the back end of the application. Decides on the run time whether call to the Local repository or Remote repository has to be made.
 *
 */
public class AccountRepository extends AbstractDomainObjectRepository<Account, AccountKey>{
	/**
	 * Singleton instance of the repository.
	 */
	private static AccountRepository singletonInstance = new AccountRepository();
	
	/**
	 * Variable to store Repository adapter value.
	 */
	private String ACCOUNT_REPOSITORY_ADAPTER = "ACCOUNT_CZ_REPOSITORY_ADAPTER";

	/**
	 * Private default constructor of the Repository.
	 */
	private AccountRepository() {

	}

	/**
	 * This method returns unique instance of {@link AccountRepository}.
	 * 
	 * @return accountRepository
	 */
	public static AccountRepository getInstance() {
		if (singletonInstance == null) {
			synchronized (AccountRepository.class) {
				if (singletonInstance == null) {
					singletonInstance = new AccountRepository();
				}
			}
		}
		return singletonInstance;
	}

	/**
	 * Fetches Account related details from the repository. It decides in run time whether a call has to be made to Local 
	 * repository or Remote repository.
	 * 
	 * @param account
	 *            Account Object containing request details.
	 * @return Account object containing response details
	 * @throws Exception from the repository in case of failure.
	 */
	public Account fetch(Account account) throws com.ofss.digx.infra.exceptions.Exception {
		IAccountRepositoryAdapter repositoryAdapter = (IAccountRepositoryAdapter) RepositoryAdapterFactory
				.getInstance().getRepositoryAdapter(
						ACCOUNT_REPOSITORY_ADAPTER);
		if(repositoryAdapter == null){
			repositoryAdapter = new RemoteAccountRepositoryAdapter();
		}
		
		return repositoryAdapter.fetch(account);
	}
	/**
	 * Method to override
	 */
	@Override
	public void create(Account arg0)
			throws com.ofss.digx.infra.exceptions.Exception {
		
	}
	/**
	 * Method to override
	 */
	@Override
	public void delete(Account arg0)
			throws com.ofss.digx.infra.exceptions.Exception {
		
	}
	/**
	 * Method to override
	 */
	@Override
	public Account read(AccountKey arg0)
			throws com.ofss.digx.infra.exceptions.Exception {
		return null;
	}
	/**
	 * Method to override
	 */
	@Override
	public void update(Account arg0)
			throws com.ofss.digx.infra.exceptions.Exception {
		
	}

	
}
