/*******************************************************************************
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 *******************************************************************************/
package com.ofss.digx.domain.account.entity.repository.adapter;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.ofss.digx.app.adapter.AdapterFactoryConfigurator;
import com.ofss.digx.app.adapter.IAdapterFactory;
import com.ofss.digx.domain.account.entity.Account;
import com.ofss.digx.domain.account.entity.AccountKey;
import com.ofss.digx.domain.account.entity.assembler.AccountDomainAssembler;
import com.ofss.digx.infra.exceptions.Exception;
import com.ofss.fc.infra.log.impl.MultiEntityLogger;

/**
 * Implementation class for {@link IAccountRepositoryAdapter}. It calls Remote adapters responsible for communicating with the external host system.
 * 
 */
public class RemoteAccountRepositoryAdapter implements IAccountRepositoryAdapter{
	/**
	 * The component name for this class.
	 */
	private static final String THIS_COMPONENT_NAME = RemoteAccountRepositoryAdapter.class.getName();

	/**
	 * Instance of formatter.
	 */
	private static final MultiEntityLogger FORMATTER = MultiEntityLogger.getUniqueInstance();

	/**
	 * Instance of java.util.logging.Logger
	 */
	private static final Logger LOGGER = FORMATTER.getLogger(THIS_COMPONENT_NAME);
	/**
	 * Constant to store Account Adapter value
	 */
	private String ACCOUNT_ADAPTER_FACTORY = "ACCOUNT_CZ_ADAPTER_FACTORY";
	/**
	 * Constant for Account Adapter
	 */
	private String ACCOUNT_ADAPTER = "ACCOUNT_ADAPTER";
	
	/**
	 * Method to override
	 */
	@Override
	public void create(Account arg0) throws Exception {
		
	}
	/**
	 * Method to override
	 */
	@Override
	public void delete(Account arg0) throws Exception {
		
	}
	/**
	 * Method to override
	 */
	@Override
	public Boolean isSimulationSupported() {
		return null;
	}
	/**
	 * Method to override
	 */
	@Override
	public Account read(AccountKey arg0) throws Exception {
		return null;
	}
	/**
	 * Method to override
	 */
	@Override
	public void update(Account arg0) throws Exception {
		
	}
	 /**
	  * Fetches account details from Remote or external system.
	  * @param account domain object containing request parameters
	  * @return account domain object containing response values
	  * @throws Exception in case of any failure while making call to repository adapter.
	  */
	@Override
	public Account fetch(Account account) throws Exception {
		if (LOGGER.isLoggable(Level.FINE)) {
			LOGGER.log(Level.FINE, FORMATTER.formatMessage("Entering fetch method of class:%s, account:%s",
					THIS_COMPONENT_NAME, account));
		}
		IAdapterFactory factory = AdapterFactoryConfigurator.getInstance().getAdapterFactory(
				ACCOUNT_ADAPTER_FACTORY);
		com.ofss.digx.app.account.adapter.IAccountAdapter adapter = (com.ofss.digx.app.account.adapter.IAccountAdapter) factory.getAdapter(ACCOUNT_ADAPTER);
		AccountDomainAssembler domainAssembler = new AccountDomainAssembler();		
		return domainAssembler.toDomainObject(adapter.fetch(domainAssembler.fromDomainObject(account)));
	}
	
}
